@@ -4,7 +4,6 @@
 
 from b2ginstance import B2GInstance
 import datetime
-from errors import *
 from mozdevice import devicemanagerADB, DMError
 from mozprocess import ProcessHandlerMixin
 import os
@@ -21,6 +20,15 @@ import traceback
 from emulator_battery import EmulatorBattery
 from emulator_geo import EmulatorGeo
 from emulator_screen import EmulatorScreen
+from decorators import uses_marionette
+
+from errors import (
+    InstallGeckoError,
+    InvalidResponseException,
+    MarionetteException,
+    ScriptTimeoutException,
+    TimeoutException
+)
 
 
 class LogOutputProc(ProcessHandlerMixin):
@@ -51,6 +59,9 @@ class Emulator(object):
     prefs = {'app.update.enabled': False,
              'app.update.staging.enabled': False,
              'app.update.service.enabled': False}
+    env = {'MOZ_CRASHREPORTER': '1',
+           'MOZ_CRASHREPORTER_NO_REPORT': '1',
+           'MOZ_CRASHREPORTER_SHUTDOWN': '1'}
 
     def __init__(self, homedir=None, noWindow=False, logcat_dir=None,
                  arch="x86", emulatorBinary=None, res=None, sdcard=None,
@@ -256,9 +267,8 @@ class Emulator(object):
         else:
             self._adb_started = False
 
+    @uses_marionette
     def wait_for_system_message(self, marionette):
-        marionette.start_session()
-        marionette.set_context(marionette.CONTEXT_CHROME)
         marionette.set_script_timeout(45000)
         # Telephony API's won't be available immediately upon emulator
         # boot; we have to wait for the syste-message-listener-ready
@@ -282,9 +292,7 @@ waitFor(
         except InvalidResponseException:
             self.check_for_minidumps()
             raise
-        print 'done'
-        marionette.set_context(marionette.CONTEXT_CONTENT)
-        marionette.delete_session()
+        print '...done'
 
     def connect(self):
         self.adb = B2GInstance.check_adb(self.homedir, emulator=True)
@@ -355,14 +363,10 @@ waitFor(
         # setup DNS fix for networking
         self._run_adb(['shell', 'setprop', 'net.dns1', '10.0.2.3'])
 
+    @uses_marionette
     def wait_for_homescreen(self, marionette):
         print 'waiting for homescreen...'
 
-        created_session = False
-        if not marionette.session:
-            marionette.start_session()
-            created_session = True
-
         marionette.set_context(marionette.CONTEXT_CONTENT)
         marionette.execute_async_script("""
 log('waiting for mozbrowserloadend');
@@ -374,10 +378,9 @@ window.addEventListener('mozbrowserloadend', function loaded(aEvent) {
   }
 });""", script_timeout=120000)
         print '...done'
-        if created_session:
-            marionette.delete_session()
 
     def setup(self, marionette, gecko_path=None, busybox=None):
+        self.set_environment(marionette)
         if busybox:
             self.install_busybox(busybox)
 
@@ -387,9 +390,17 @@ window.addEventListener('mozbrowserloadend', function loaded(aEvent) {
         self.wait_for_system_message(marionette)
         self.set_prefs(marionette)
 
+    @uses_marionette
+    def set_environment(self, marionette):
+        for k, v in self.env.iteritems():
+            marionette.execute_script("""
+            let env = Cc["@mozilla.org/process/environment;1"].
+                      getService(Ci.nsIEnvironment);
+            env.set("%s", "%s");
+            """ % (k, v))
+
+    @uses_marionette
     def set_prefs(self, marionette):
-        marionette.start_session()
-        marionette.set_context(marionette.CONTEXT_CHROME)
         for pref in self.prefs:
             marionette.execute_script("""
             Components.utils.import("resource://gre/modules/Services.jsm");
@@ -405,7 +416,6 @@ window.addEventListener('mozbrowserloadend', function loaded(aEvent) {
                     Services.prefs.setCharPref(arguments[0], arguments[1]);
             }
             """, [pref, self.prefs[pref]])
-        marionette.delete_session()
 
     def restart_b2g(self):
         print 'restarting B2G'
